textatopics: The textatopics object
Description
The textatopics object exposes formatted results for the
textaDetectTopics API, this REST API's JSON response, and the
HTTP request:
-
status the operation's current status ("NotStarted"|"Running"|"Succeeded"|"Failed")
-
documents a data.frame with the documents and a unique
string ID for each
-
topics a data.frame with the identified topics, a
unique string ID for each, and a prevalence score for each topic (count of
documents assigned to topic)
-
topicAssignments a data.frame with all the topics
(identified by their topic ID) assigned to each document (identified by
their document ID), and a distance score for each topic assignment (between
0 and 1; the lower the distance score the stronger the topic affiliation)
-
json the REST API JSON response
-
request the HTTP request
See Also
Other res: texta